Changelog
=========

0.1 (????-??-??)
----------------

Initial version


0.2 (????-??-??)
----------------

Changes:

- switch to Python 3
- update the docstrings
- change the package name (`pyai`)
- miscellaneous updates and bug fixes

Packaging:

- write the `setup.py` file
- write a script to automatically build the Debian package

